# frozen_string_literal: true

module Jekyll
  module Filters
    module Assertion
      # Compares two values.
      #
      # Example usage:
      #
      # {{ item.url | equals: page.url }}
      #
      # @param [Any]
      # @param [Any]
      # @return [TrueClass|FalseClass]
      def equals(input, comparison)
        input == comparison
      end

      # Ternary operator.  If the input value is truthy, return first
      # argument, otherwise returns the last.
      #
      # Example usage:
      #
      # {% assign active = item.url | equals: page.url %}
      # {{ active | ternary: 'active', '' }}
      #
      # @param [Any]
      # @param [Any]
      # @param [Any]
      # @return [Any]
      def ternary(input, value, alternative)
        empty = case input
                when Integer then input.zero?
                when Float then input.zero?
                when TrueClass then input
                when FalseClass then input
                when NilClass then false
                else input.empty?
                end

        (empty || !!input) ? value : alternative
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::Assertion)
